Documentation
¶
Index ¶
- Variables
- type CompletionMessage
- func (*CompletionMessage) Descriptor() ([]byte, []int)deprecated
- func (x *CompletionMessage) GetContent() []*ContentBlock
- func (x *CompletionMessage) GetData() string
- func (x *CompletionMessage) GetRole() string
- func (*CompletionMessage) ProtoMessage()
- func (x *CompletionMessage) ProtoReflect() protoreflect.Message
- func (x *CompletionMessage) Reset()
- func (x *CompletionMessage) String() string
- func (m *CompletionMessage) Validate() error
- func (m *CompletionMessage) ValidateAll() error
- type CompletionMessageMultiError
- type CompletionMessageValidationError
- func (e CompletionMessageValidationError) Cause() error
- func (e CompletionMessageValidationError) Error() string
- func (e CompletionMessageValidationError) ErrorName() string
- func (e CompletionMessageValidationError) Field() string
- func (e CompletionMessageValidationError) Key() bool
- func (e CompletionMessageValidationError) Reason() string
- type ContentBlock
- func (*ContentBlock) Descriptor() ([]byte, []int)deprecated
- func (m *ContentBlock) GetBlockType() isContentBlock_BlockType
- func (x *ContentBlock) GetText() string
- func (x *ContentBlock) GetToolCall() *ToolCall
- func (x *ContentBlock) GetToolResult() *ToolResult
- func (*ContentBlock) ProtoMessage()
- func (x *ContentBlock) ProtoReflect() protoreflect.Message
- func (x *ContentBlock) Reset()
- func (x *ContentBlock) String() string
- func (m *ContentBlock) Validate() error
- func (m *ContentBlock) ValidateAll() error
- type ContentBlockMultiError
- type ContentBlockValidationError
- func (e ContentBlockValidationError) Cause() error
- func (e ContentBlockValidationError) Error() string
- func (e ContentBlockValidationError) ErrorName() string
- func (e ContentBlockValidationError) Field() string
- func (e ContentBlockValidationError) Key() bool
- func (e ContentBlockValidationError) Reason() string
- type ContentBlock_Text
- type ContentBlock_ToolCall
- type ContentBlock_ToolResult
- type Tool
- func (*Tool) Descriptor() ([]byte, []int)deprecated
- func (x *Tool) GetDescription() string
- func (x *Tool) GetDisplayName() string
- func (x *Tool) GetInputSchema() string
- func (x *Tool) GetMeta() *structpb.Struct
- func (x *Tool) GetName() string
- func (x *Tool) GetOutputSchema() string
- func (*Tool) ProtoMessage()
- func (x *Tool) ProtoReflect() protoreflect.Message
- func (x *Tool) Reset()
- func (x *Tool) String() string
- func (m *Tool) Validate() error
- func (m *Tool) ValidateAll() error
- type ToolCall
- func (*ToolCall) Descriptor() ([]byte, []int)deprecated
- func (x *ToolCall) GetId() string
- func (x *ToolCall) GetInput() *structpb.Struct
- func (x *ToolCall) GetName() string
- func (*ToolCall) ProtoMessage()
- func (x *ToolCall) ProtoReflect() protoreflect.Message
- func (x *ToolCall) Reset()
- func (x *ToolCall) String() string
- func (m *ToolCall) Validate() error
- func (m *ToolCall) ValidateAll() error
- type ToolCallMultiError
- type ToolCallValidationError
- type ToolMultiError
- type ToolResult
- func (*ToolResult) Descriptor() ([]byte, []int)deprecated
- func (x *ToolResult) GetContent() string
- func (x *ToolResult) GetId() string
- func (x *ToolResult) GetIsError() bool
- func (*ToolResult) ProtoMessage()
- func (x *ToolResult) ProtoReflect() protoreflect.Message
- func (x *ToolResult) Reset()
- func (x *ToolResult) String() string
- func (m *ToolResult) Validate() error
- func (m *ToolResult) ValidateAll() error
- type ToolResultMultiError
- type ToolResultValidationError
- type ToolValidationError
Constants ¶
This section is empty.
Variables ¶
var File_rill_ai_v1_ai_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type CompletionMessage ¶
type CompletionMessage struct {
Role string `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`
Data string `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"` // Deprecated in favor of content
Content []*ContentBlock `protobuf:"bytes,3,rep,name=content,proto3" json:"content,omitempty"`
// contains filtered or unexported fields
}
Completion message for AI API calls
func (*CompletionMessage) Descriptor
deprecated
func (*CompletionMessage) Descriptor() ([]byte, []int)
Deprecated: Use CompletionMessage.ProtoReflect.Descriptor instead.
func (*CompletionMessage) GetContent ¶
func (x *CompletionMessage) GetContent() []*ContentBlock
func (*CompletionMessage) GetData ¶
func (x *CompletionMessage) GetData() string
func (*CompletionMessage) GetRole ¶
func (x *CompletionMessage) GetRole() string
func (*CompletionMessage) ProtoMessage ¶
func (*CompletionMessage) ProtoMessage()
func (*CompletionMessage) ProtoReflect ¶
func (x *CompletionMessage) ProtoReflect() protoreflect.Message
func (*CompletionMessage) Reset ¶
func (x *CompletionMessage) Reset()
func (*CompletionMessage) String ¶
func (x *CompletionMessage) String() string
func (*CompletionMessage) Validate ¶
func (m *CompletionMessage) Validate() error
Validate checks the field values on CompletionMessage with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*CompletionMessage) ValidateAll ¶
func (m *CompletionMessage) ValidateAll() error
ValidateAll checks the field values on CompletionMessage with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CompletionMessageMultiError, or nil if none found.
type CompletionMessageMultiError ¶
type CompletionMessageMultiError []error
CompletionMessageMultiError is an error wrapping multiple validation errors returned by CompletionMessage.ValidateAll() if the designated constraints aren't met.
func (CompletionMessageMultiError) AllErrors ¶
func (m CompletionMessageMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (CompletionMessageMultiError) Error ¶
func (m CompletionMessageMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type CompletionMessageValidationError ¶
type CompletionMessageValidationError struct {
// contains filtered or unexported fields
}
CompletionMessageValidationError is the validation error returned by CompletionMessage.Validate if the designated constraints aren't met.
func (CompletionMessageValidationError) Cause ¶
func (e CompletionMessageValidationError) Cause() error
Cause function returns cause value.
func (CompletionMessageValidationError) Error ¶
func (e CompletionMessageValidationError) Error() string
Error satisfies the builtin error interface
func (CompletionMessageValidationError) ErrorName ¶
func (e CompletionMessageValidationError) ErrorName() string
ErrorName returns error name.
func (CompletionMessageValidationError) Field ¶
func (e CompletionMessageValidationError) Field() string
Field function returns field value.
func (CompletionMessageValidationError) Key ¶
func (e CompletionMessageValidationError) Key() bool
Key function returns key value.
func (CompletionMessageValidationError) Reason ¶
func (e CompletionMessageValidationError) Reason() string
Reason function returns reason value.
type ContentBlock ¶
type ContentBlock struct {
// Types that are assignable to BlockType:
//
// *ContentBlock_Text
// *ContentBlock_ToolCall
// *ContentBlock_ToolResult
BlockType isContentBlock_BlockType `protobuf_oneof:"block_type"`
// contains filtered or unexported fields
}
Content block within a message
func (*ContentBlock) Descriptor
deprecated
func (*ContentBlock) Descriptor() ([]byte, []int)
Deprecated: Use ContentBlock.ProtoReflect.Descriptor instead.
func (*ContentBlock) GetBlockType ¶
func (m *ContentBlock) GetBlockType() isContentBlock_BlockType
func (*ContentBlock) GetText ¶
func (x *ContentBlock) GetText() string
func (*ContentBlock) GetToolCall ¶
func (x *ContentBlock) GetToolCall() *ToolCall
func (*ContentBlock) GetToolResult ¶
func (x *ContentBlock) GetToolResult() *ToolResult
func (*ContentBlock) ProtoMessage ¶
func (*ContentBlock) ProtoMessage()
func (*ContentBlock) ProtoReflect ¶
func (x *ContentBlock) ProtoReflect() protoreflect.Message
func (*ContentBlock) Reset ¶
func (x *ContentBlock) Reset()
func (*ContentBlock) String ¶
func (x *ContentBlock) String() string
func (*ContentBlock) Validate ¶
func (m *ContentBlock) Validate() error
Validate checks the field values on ContentBlock with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ContentBlock) ValidateAll ¶
func (m *ContentBlock) ValidateAll() error
ValidateAll checks the field values on ContentBlock with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ContentBlockMultiError, or nil if none found.
type ContentBlockMultiError ¶
type ContentBlockMultiError []error
ContentBlockMultiError is an error wrapping multiple validation errors returned by ContentBlock.ValidateAll() if the designated constraints aren't met.
func (ContentBlockMultiError) AllErrors ¶
func (m ContentBlockMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ContentBlockMultiError) Error ¶
func (m ContentBlockMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ContentBlockValidationError ¶
type ContentBlockValidationError struct {
// contains filtered or unexported fields
}
ContentBlockValidationError is the validation error returned by ContentBlock.Validate if the designated constraints aren't met.
func (ContentBlockValidationError) Cause ¶
func (e ContentBlockValidationError) Cause() error
Cause function returns cause value.
func (ContentBlockValidationError) Error ¶
func (e ContentBlockValidationError) Error() string
Error satisfies the builtin error interface
func (ContentBlockValidationError) ErrorName ¶
func (e ContentBlockValidationError) ErrorName() string
ErrorName returns error name.
func (ContentBlockValidationError) Field ¶
func (e ContentBlockValidationError) Field() string
Field function returns field value.
func (ContentBlockValidationError) Key ¶
func (e ContentBlockValidationError) Key() bool
Key function returns key value.
func (ContentBlockValidationError) Reason ¶
func (e ContentBlockValidationError) Reason() string
Reason function returns reason value.
type ContentBlock_Text ¶
type ContentBlock_Text struct {
Text string `protobuf:"bytes,1,opt,name=text,proto3,oneof"`
}
type ContentBlock_ToolCall ¶
type ContentBlock_ToolCall struct {
ToolCall *ToolCall `protobuf:"bytes,2,opt,name=tool_call,json=toolCall,proto3,oneof"`
}
type ContentBlock_ToolResult ¶
type ContentBlock_ToolResult struct {
ToolResult *ToolResult `protobuf:"bytes,3,opt,name=tool_result,json=toolResult,proto3,oneof"`
}
type Tool ¶
type Tool struct {
// The name of the tool
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The display name of the tool
DisplayName string `protobuf:"bytes,4,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// A human-readable description of the tool
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// Metadata about the tool
Meta *structpb.Struct `protobuf:"bytes,5,opt,name=meta,proto3" json:"meta,omitempty"`
// JSON Schema defining the expected parameters for the tool (as JSON string)
InputSchema string `protobuf:"bytes,3,opt,name=input_schema,json=inputSchema,proto3" json:"input_schema,omitempty"`
// JSON Schema defining the expected output of the tool (as JSON string)
OutputSchema string `protobuf:"bytes,6,opt,name=output_schema,json=outputSchema,proto3" json:"output_schema,omitempty"`
// contains filtered or unexported fields
}
Tool represents a tool definition for AI usage
func (*Tool) Descriptor
deprecated
func (*Tool) GetDescription ¶
func (*Tool) GetDisplayName ¶
func (*Tool) GetInputSchema ¶
func (*Tool) GetOutputSchema ¶
func (*Tool) ProtoMessage ¶
func (*Tool) ProtoMessage()
func (*Tool) ProtoReflect ¶
func (x *Tool) ProtoReflect() protoreflect.Message
func (*Tool) Validate ¶
Validate checks the field values on Tool with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*Tool) ValidateAll ¶
ValidateAll checks the field values on Tool with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ToolMultiError, or nil if none found.
type ToolCall ¶
type ToolCall struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Input *structpb.Struct `protobuf:"bytes,3,opt,name=input,proto3" json:"input,omitempty"`
// contains filtered or unexported fields
}
Tool call specification
func (*ToolCall) Descriptor
deprecated
func (*ToolCall) ProtoMessage ¶
func (*ToolCall) ProtoMessage()
func (*ToolCall) ProtoReflect ¶
func (x *ToolCall) ProtoReflect() protoreflect.Message
func (*ToolCall) Validate ¶
Validate checks the field values on ToolCall with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ToolCall) ValidateAll ¶
ValidateAll checks the field values on ToolCall with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ToolCallMultiError, or nil if none found.
type ToolCallMultiError ¶
type ToolCallMultiError []error
ToolCallMultiError is an error wrapping multiple validation errors returned by ToolCall.ValidateAll() if the designated constraints aren't met.
func (ToolCallMultiError) AllErrors ¶
func (m ToolCallMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ToolCallMultiError) Error ¶
func (m ToolCallMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ToolCallValidationError ¶
type ToolCallValidationError struct {
// contains filtered or unexported fields
}
ToolCallValidationError is the validation error returned by ToolCall.Validate if the designated constraints aren't met.
func (ToolCallValidationError) Cause ¶
func (e ToolCallValidationError) Cause() error
Cause function returns cause value.
func (ToolCallValidationError) Error ¶
func (e ToolCallValidationError) Error() string
Error satisfies the builtin error interface
func (ToolCallValidationError) ErrorName ¶
func (e ToolCallValidationError) ErrorName() string
ErrorName returns error name.
func (ToolCallValidationError) Field ¶
func (e ToolCallValidationError) Field() string
Field function returns field value.
func (ToolCallValidationError) Key ¶
func (e ToolCallValidationError) Key() bool
Key function returns key value.
func (ToolCallValidationError) Reason ¶
func (e ToolCallValidationError) Reason() string
Reason function returns reason value.
type ToolMultiError ¶
type ToolMultiError []error
ToolMultiError is an error wrapping multiple validation errors returned by Tool.ValidateAll() if the designated constraints aren't met.
func (ToolMultiError) AllErrors ¶
func (m ToolMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ToolMultiError) Error ¶
func (m ToolMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ToolResult ¶
type ToolResult struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Content string `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"`
IsError bool `protobuf:"varint,3,opt,name=is_error,json=isError,proto3" json:"is_error,omitempty"`
// contains filtered or unexported fields
}
Tool execution result
func (*ToolResult) Descriptor
deprecated
func (*ToolResult) Descriptor() ([]byte, []int)
Deprecated: Use ToolResult.ProtoReflect.Descriptor instead.
func (*ToolResult) GetContent ¶
func (x *ToolResult) GetContent() string
func (*ToolResult) GetId ¶
func (x *ToolResult) GetId() string
func (*ToolResult) GetIsError ¶
func (x *ToolResult) GetIsError() bool
func (*ToolResult) ProtoMessage ¶
func (*ToolResult) ProtoMessage()
func (*ToolResult) ProtoReflect ¶
func (x *ToolResult) ProtoReflect() protoreflect.Message
func (*ToolResult) Reset ¶
func (x *ToolResult) Reset()
func (*ToolResult) String ¶
func (x *ToolResult) String() string
func (*ToolResult) Validate ¶
func (m *ToolResult) Validate() error
Validate checks the field values on ToolResult with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ToolResult) ValidateAll ¶
func (m *ToolResult) ValidateAll() error
ValidateAll checks the field values on ToolResult with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ToolResultMultiError, or nil if none found.
type ToolResultMultiError ¶
type ToolResultMultiError []error
ToolResultMultiError is an error wrapping multiple validation errors returned by ToolResult.ValidateAll() if the designated constraints aren't met.
func (ToolResultMultiError) AllErrors ¶
func (m ToolResultMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ToolResultMultiError) Error ¶
func (m ToolResultMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ToolResultValidationError ¶
type ToolResultValidationError struct {
// contains filtered or unexported fields
}
ToolResultValidationError is the validation error returned by ToolResult.Validate if the designated constraints aren't met.
func (ToolResultValidationError) Cause ¶
func (e ToolResultValidationError) Cause() error
Cause function returns cause value.
func (ToolResultValidationError) Error ¶
func (e ToolResultValidationError) Error() string
Error satisfies the builtin error interface
func (ToolResultValidationError) ErrorName ¶
func (e ToolResultValidationError) ErrorName() string
ErrorName returns error name.
func (ToolResultValidationError) Field ¶
func (e ToolResultValidationError) Field() string
Field function returns field value.
func (ToolResultValidationError) Key ¶
func (e ToolResultValidationError) Key() bool
Key function returns key value.
func (ToolResultValidationError) Reason ¶
func (e ToolResultValidationError) Reason() string
Reason function returns reason value.
type ToolValidationError ¶
type ToolValidationError struct {
// contains filtered or unexported fields
}
ToolValidationError is the validation error returned by Tool.Validate if the designated constraints aren't met.
func (ToolValidationError) Cause ¶
func (e ToolValidationError) Cause() error
Cause function returns cause value.
func (ToolValidationError) Error ¶
func (e ToolValidationError) Error() string
Error satisfies the builtin error interface
func (ToolValidationError) ErrorName ¶
func (e ToolValidationError) ErrorName() string
ErrorName returns error name.
func (ToolValidationError) Field ¶
func (e ToolValidationError) Field() string
Field function returns field value.
func (ToolValidationError) Key ¶
func (e ToolValidationError) Key() bool
Key function returns key value.
func (ToolValidationError) Reason ¶
func (e ToolValidationError) Reason() string
Reason function returns reason value.